<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>밝기 설정</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;백라이트 및 밝기 설정:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>백라이트</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>밝기</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>설정 변경 후 확인 필요</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="54"/>
        <source>Currently unsupported under Wayland</source>
        <translation>현재 Wayland 환경에서 지원되지 않음</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="122"/>
        <source>Brightness settings changed</source>
        <translation>밝기 설정이 변경됨</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="123"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>확인이 필요합니다. 설정이 올바릅니까?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;출력:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Increase brightness.</source>
        <translation>밝기를 높입니다.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Decrease brightness.</source>
        <translation>밝기를 줄입니다.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>밝기를 1에서 100까지 설정합니다.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Reset gamma to default value.</source>
        <translation>감마를 기본값으로 재설정합니다.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="114"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: 증가/감소 및 설정을 함께 사용할 수 없습니다</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="119"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: 증가 및 감소 옵션을 함께 사용할 수 없습니다</translation>
    </message>
</context>
</TS>
